@@ -21,38 +21,22 @@ class BotManager(Client):
     _is_connected = False
     _rename = False
     _flood_data = {}
-    TOKEN_INDEX = 0
     _loop = None
     _scheduler_thread = None
     font = 0
     sudo_users = []
 
 
-    def create_client(self,token_index):
+    def create_client(self,app_name,token):
         super().__init__(
-            name=self.app_name,
+            name=app_name,
             api_id=self.api_id,
             api_hash=self.api_hash,
-            bot_token=self.tokens[token_index],
+            bot_token=token,
             plugins=self.plugins,
             in_memory=True
             )
 
-    def load_flood_data(self):
-        if not os.path.exists('flood.txt'):
-            return self._flood_data
-
-        with open('flood.txt', "r") as f:
-            for line in f:
-                if ":" not in line:
-                    continue
-                try:
-                    token_index, until = map(int, line.strip().split(":"))
-                    if token_index not in self._flood_data or until > self._flood_data[token_index]:
-                        self._flood_data[token_index] = until
-                except:
-                    continue
-
     async def handle_flood_wait(self, wait_time: int):
         logger.info(f"FloodWait: Sleeping for {wait_time} seconds.")
 
@@ -64,48 +48,9 @@ class BotManager(Client):
         if self._loop:asyncio.run_coroutine_threadsafe(coro_func(), self._loop)
         else:logger.error("Event loop is not set for _safe_async")
 
-    def get_token_index_from_flood_file(self):
-        if not os.path.exists("flood.txt"):
-            return random.choice(range(len(self.tokens)))
-        now = int(datetime.now(self.TZ).timestamp())
-        flooded = []
-        non_flooded = []
-        for i in range(len(self.tokens)):
-            until = self._flood_data.get(i, 0)
-            if until <= now:
-                logger.info(f"Token 0{i + 1} is not in flood.")
-                self._flood_data.pop(i, None)
-                self.save_flood_data()
-                non_flooded.append((i))
-            else:
-                flooded.append((i, until))
-        if non_flooded != []:
-            return random.choice(non_flooded)
-        logger.warning("All tokens are in flood. Picking the one with the soonest expiry.")
-        flooded.sort(key=lambda x: x[1])
-        return flooded[0][0]
-    def save_flood_data(self):
-        with open('flood.txt', "w") as f:
-            for token_index, until in self._flood_data.items():
-                f.write(f"{token_index}:{until}\n")
+    
 
-    async def change_token(self, token_index,wait_time):
-        flood_until = datetime.now(self.TZ) + timedelta(seconds=wait_time)
-        self._flood_data[token_index] = int(flood_until.timestamp())
-        self.save_flood_data()
-        try:
-            self.TOKEN_INDEX = token_index + 1
-            self.create_client(self.TOKEN_INDEX)
-            await asyncio.sleep(2)
-        except:
-            self.TOKEN_INDEX = 0
-            self.create_client(self.TOKEN_INDEX)
-            await self.handle_flood_wait(wait_time)
-
-    async def setup_webserver(self):
-        self._web_runner = await self.web_server.setup_web_server(8443)
-
-    async def powerup(self):
+    async def powerup(self,appname):
         if hasattr(self, "db"):
             self.font = self.db.Settings.get(key="font",datatype=str)
             self.sudo_users = self.db.Settings.get(key="sudo_users",datatype=list,default=[])
@@ -115,9 +60,7 @@ class BotManager(Client):
                 self.db.Settings.set("font", "1")
                 self.font = 1
 
-        self.load_flood_data()
-        self.TOKEN_INDEX= self.get_token_index_from_flood_file()
-        self.create_client(self.TOKEN_INDEX)
+        self.create_client(appname,self.token)
         max_retries = 3
         for attempt in range(max_retries):
             try:
@@ -129,7 +72,6 @@ class BotManager(Client):
                     logger.info(f"Bot Client > {self._bot_info.first_name} - @{self._bot_info.username} Started")
                     await self.setup_commands()
                     self._is_connected = True
-                    await self.start_scheduler()
                     await self.handle_restart()
                     break 
 
@@ -141,11 +83,9 @@ class BotManager(Client):
                 
             except FloodWait as e:
                 logger.error(f"FloodWait: {e.value} seconds")
-                await self.change_token(self.TOKEN_INDEX,e.value)
-                
+                await self.handle_flood_wait(e.value)
             except AccessTokenExpired:
                 logger.error(f"Access token expired (attempt {attempt + 1})")
-                await self.change_token(self.TOKEN_INDEX, 60)
             except Exception as e:
                 logger.error(f"Error starting Client (attempt {attempt + 1}): {e}")
                 logger.error(traceback.format_exc())
